==> prtg-config-xml-3.0.0-sources.jar: org/adeptnet/prtg/config/NewMain.java <==
/*
 * Copyright 2016 Francois Steyn - Adept Internet (PTY) LTD (francois.s@adept.co.za).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.adeptnet.prtg.config;

import java.io.File;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.xml.bind.JAXBException;

/**
 *
 * @author Francois Steyn - Adept Internet (PTY) LTD (francois.s@adept.co.za)
 */
public class NewMain {

    private static final Logger LOG = Logger.getLogger(NewMain.class.getName());

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        // TODO code application logic here
        final NewMain m = new NewMain();
        m.run();
    }

    private void run() {
        try {
            LOG.fine("asdf");
            //final org.adeptnet.prtg.xml.JaxbManager jaxb = new org.adeptnet.prtg.xml.JaxbManager();
            final org.adeptnet.prtg.config.xml.JaxbManager jaxb = new org.adeptnet.prtg.config.xml.JaxbManager();
            //final Object o = jaxb.fromXML(new File("C:\\adept\\aims\\aims-deploy\\src\\main\\deploy\\prod\\aims.adept.co.za\\etc\\aims-server\\server.xml"), Object.class);
            //final Object o = jaxb.fromXML(new File("C:\\Program Files\\Apache Software Foundation\\apache-servicemix-5.4.0\\etc\\org.adeptnet.prtg.xml"), Object.class);
            //final org.adeptnet.prtg.config.xml.Config o = jaxb.toConfig(new File("C:\\Program Files\\Apache Software Foundation\\apache-servicemix-5.4.0\\etc\\org.adeptnet.prtg.xml"));
            final org.adeptnet.prtg.config.xml.Config o = jaxb.toConfig(new File("C:\\adept\\prtg-java\\org.adeptnet.prtg.xml"));
            final String str = jaxb.toXML(o);
            LOG.log(Level.INFO, str);
        } catch (JAXBException ex) {
            LOG.log(Level.SEVERE, ex.getMessage(), ex);
        }

    }

}

==> prtg-config-xml-3.0.1-sources.jar: org/adeptnet/prtg/config/NewMain.java <==
/*
 * Copyright 2016 Francois Steyn - Adept Internet (PTY) LTD (francois.s@adept.co.za).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.adeptnet.prtg.config;

import java.io.File;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.xml.bind.JAXBException;

/**
 *
 * @author Francois Steyn - Adept Internet (PTY) LTD (francois.s@adept.co.za)
 */
public class NewMain {

    private static final Logger LOG = Logger.getLogger(NewMain.class.getName());

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        // TODO code application logic here
        final NewMain m = new NewMain();
        m.run();
    }

    private void run() {
        try {
            LOG.fine("asdf");
            //final org.adeptnet.prtg.xml.JaxbManager jaxb = new org.adeptnet.prtg.xml.JaxbManager();
            final org.adeptnet.prtg.config.xml.JaxbManager jaxb = new org.adeptnet.prtg.config.xml.JaxbManager();
            //final Object o = jaxb.fromXML(new File("C:\\adept\\aims\\aims-deploy\\src\\main\\deploy\\prod\\aims.adept.co.za\\etc\\aims-server\\server.xml"), Object.class);
            //final Object o = jaxb.fromXML(new File("C:\\Program Files\\Apache Software Foundation\\apache-servicemix-5.4.0\\etc\\org.adeptnet.prtg.xml"), Object.class);
            final org.adeptnet.prtg.config.xml.Config o = jaxb.toConfig(new File("C:\\Program Files\\Apache Software Foundation\\apache-servicemix-5.4.0\\etc\\org.adeptnet.prtg.xml"));
            //final org.adeptnet.prtg.config.xml.Config o = jaxb.toConfig(new File("C:\\adept\\prtg-java\\org.adeptnet.prtg.xml"));
            final String str = jaxb.toXML(o);
            LOG.log(Level.INFO, str);
        } catch (JAXBException ex) {
            LOG.log(Level.SEVERE, ex.getMessage(), ex);
        }

    }

}
